@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: FileAccess.h,v 1.104 2007/09/10 09:56:27 lav Exp $ */
+/* $Id: FileAccess.h,v 1.105 2007/11/12 05:20:32 lav Exp $ */
 
 #ifndef FILEACCESS_H
 #define FILEACCESS_H
@@ -145,7 +145,7 @@ protected:
    static void NonBlock(int fd);
    static void CloseOnExec(int fd);
 
-   static void Log2(int level,const char *str);
+   static void Log2(int level,xstring& str);
    static void Log3(int level,const char *prefix,const char *str);
 
    time_t try_time;
