@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: FileCopy.cc,v 1.142 2007/09/10 09:57:53 lav Exp $ */
+/* $Id: FileCopy.cc,v 1.144 2007/12/28 10:23:09 lav Exp $ */
 
 /* FileCopyPeer behaviour:
     1) when suspended, does nothing
@@ -512,8 +512,8 @@ const char *FileCopy::GetPercentDoneStr()
    int pct=GetPercentDone();
    if(pct==-1)
       return "";
-   static char buf[6];
-   sprintf(buf,"(%d%%) ",pct);
+   static char buf[8];
+   snprintf(buf,8,"(%d%%) ",pct);
    return buf;
 }
 float FileCopy::GetRate()
@@ -1039,7 +1039,7 @@ int FileCopyPeerFA::Get_LL(int len)
 	       if(orig_url)
 	       {
 		  int p_ind=url::path_index(orig_url);
-		  char *s=strrchr(orig_url,'/');
+		  const char *s=strrchr(orig_url,'/');
 		  int s_ind=s?s-orig_url:-1;
 		  if(p_ind==-1 || s_ind==-1 || s_ind<p_ind)
 		     s_ind=p_ind=strlen(orig_url);
