@@ -1,7 +1,7 @@
 /*
  * lftp - file transfer program
  *
- * Copyright (c) 2000-2006 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 2000-2008 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,6 +19,7 @@
  */
 
 #include <config.h>
+#include <stddef.h>
 #include "Fish.h"
 #include "trio.h"
 #include <unistd.h>
@@ -1069,6 +1070,11 @@ void Fish::Reconfig(const char *name)
 	 send_buf->SetTranslation(charset,false);
 	 recv_buf->SetTranslation(charset,true);
       }
+      else
+      {
+	 send_buf->SetTranslator(0);
+	 recv_buf->SetTranslator(0);
+      }
    }
 }
 
