@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: LocalAccess.cc,v 1.60 2007/09/20 11:29:40 lav Exp $ */
+/* $Id: LocalAccess.cc,v 1.61 2007/12/28 10:23:10 lav Exp $ */
 
 #include <config.h>
 #include <errno.h>
@@ -204,15 +204,11 @@ int LocalAccess::Do()
    case(MAKE_DIR):
       if(mkdir_p)
       {
-	 char *sl=strchr(file,'/');
+	 const char *sl=strchr(file,'/');
 	 while(sl)
 	 {
 	    if(sl>file)
-	    {
-	       *sl=0;
-	       mkdir(dir_file(cwd,file),0775);
-	       *sl='/';
-	    }
+	       mkdir(dir_file(cwd,xstring::get_tmp(file,sl-file)),0775);
 	    sl=strchr(sl+1,'/');
 	 }
       }
