@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: NetAccess.h,v 1.42.2.1 2007/08/17 14:54:16 lav Exp $ */
+/* $Id: NetAccess.h,v 1.47 2007/08/08 07:08:32 lav Exp $ */
 
 #ifndef NETACCESS_H
 #define NETACCESS_H
@@ -26,15 +26,15 @@
 #include "FileAccess.h"
 #include "Resolver.h"
 #include "LsCache.h"
+#include "RateLimit.h"
 
 class NetAccess : public FileAccess
 {
 protected:
-   Resolver *resolver;
+   SMTaskRef<Resolver> resolver;
 
-   sockaddr_u *peer;
-   int	 peer_num;
-   int	 peer_curr;
+   xarray<sockaddr_u> peer;
+   int peer_curr;
    void	 ClearPeer();
    void	 NextPeer();
 
@@ -54,7 +54,7 @@ protected:
    int	 connection_limit;
    bool	 connection_takeover;
 
-   class RateLimit *rate_limit;
+   Ref<RateLimit> rate_limit;
 
    int	 socket_buffer;
    int	 socket_maxseg;
@@ -75,13 +75,13 @@ protected:
    int Poll(int fd,int ev);
    int CheckHangup(const struct pollfd *pfd,int num);
 
-   char	 *proxy;
-   char	 *proxy_port;
-   char  *proxy_user;
-   char  *proxy_pass;
-   char  *proxy_proto;
+   xstring proxy;
+   xstring proxy_port;
+   xstring proxy_user;
+   xstring proxy_pass;
+   xstring proxy_proto;
 
-   char	 *home_auto;
+   xstring home_auto;
    void	 PropagateHomeAuto();
    const char *FindHomeAuto();
 
@@ -119,54 +119,13 @@ public:
    static void ClassInit();
 };
 
-class RateLimit
-{
-public:
-   class BytesPool
-   {
-      friend class RateLimit;
-
-      int pool;
-      int rate;
-      int pool_max;
-      Time t;
-
-      void AdjustTime();
-      void Reset();
-      void Used(int);
-   };
-
-private:
-   static int total_xfer_number;
-   static bool total_reconfig_needed;
-   static void ReconfigTotal();
-   static BytesPool total[2];
-   BytesPool one[2];
-
-public:
-   RateLimit(const char *closure);
-   ~RateLimit();
-
-   enum dir_t { GET=0, PUT=1 };
-
-   int BytesAllowed(dir_t how);
-   int BytesAllowedToGet() { return BytesAllowed(GET); }
-   int BytesAllowedToPut() { return BytesAllowed(PUT); }
-   void BytesUsed(int,dir_t);
-   void BytesGot(int b) { BytesUsed(b,GET); }
-   void BytesPut(int b) { BytesUsed(b,PUT); }
-
-   void Reconfig(const char *name,const char *c);
-};
-
 class GenericParseListInfo : public ListInfo
 {
 protected:
-   FA::fileinfo *get_info;
-   int get_info_cnt;
+   xarray<FA::fileinfo> get_info;
 
    int mode;
-   IOBuffer *ubuf;
+   SMTaskRef<IOBuffer> ubuf;
 
    bool get_time_for_dirs;
    bool can_get_prec_time;
@@ -176,10 +135,8 @@ protected:
 
 public:
    GenericParseListInfo(FileAccess *session,const char *path);
-   virtual ~GenericParseListInfo();
    int Do();
    const char *Status();
 };
 
-
 #endif//NETACCESS_H
