@@ -1,7 +1,7 @@
 /*
  * lftp - file transfer program
  *
- * Copyright (c) 2003-2005 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 2003-2008 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: SFtp.cc,v 1.72 2007/10/08 13:29:15 lav Exp $ */
+/* $Id: SFtp.cc,v 1.76 2008/01/21 14:07:00 lav Exp $ */
 
 #include <config.h>
 #include "SFtp.h"
@@ -31,6 +31,7 @@
 
 #include <assert.h>
 #include <errno.h>
+#include <stddef.h>
 
 #define max_buf 0x10000
 
@@ -359,6 +360,7 @@ void SFtp::Init()
    max_packets_in_flight_slow_start=1;
    size_read=0x8000;
    size_write=0x8000;
+   use_full_path=false;
    flush_timer.Set(0,500);
 }
 
@@ -560,7 +562,9 @@ const char *SFtp::SkipHome(const char *path)
 }
 const char *SFtp::WirePath(const char *path)
 {
-   path=SkipHome(dir_file(cwd,path));
+   path=dir_file(cwd,path);
+   if(!use_full_path || path[0]=='~')
+      path=SkipHome(path);
    LogNote(9,"path on wire is `%s'",path);
    return lc_to_utf8(path);
 }
@@ -587,8 +591,13 @@ void SFtp::SendRequest()
       state=WAITING;
       break;
    case STORE:
-      SendRequest(new Request_OPEN(WirePath(file),SSH_FXF_WRITE|SSH_FXF_CREAT,
-	 ACE4_WRITE_DATA|ACE4_WRITE_ATTRIBUTES,SSH_FXF_OPEN_OR_CREATE,protocol_version),Expect::HANDLE);
+      SendRequest(
+	 new Request_OPEN(WirePath(file),
+	    SSH_FXF_WRITE|SSH_FXF_CREAT|(pos==0?SSH_FXF_TRUNC:0),
+	    ACE4_WRITE_DATA|ACE4_WRITE_ATTRIBUTES,
+	    pos==0?SSH_FXF_CREATE_TRUNCATE:SSH_FXF_OPEN_OR_CREATE,
+	    protocol_version),
+	 Expect::HANDLE);
       state=WAITING;
       break;
    case ARRAY_INFO:
@@ -833,14 +842,14 @@ void SFtp::HandleExpect(Expect *e)
 	 xstring handle_x("");
 	 int handle_len=handle.length();
 	 for(int i=0; i<handle_len; i++)
-	    handle_x.appendf("%02X",handle[i]);
+	    handle_x.appendf("%02X",(unsigned char)handle[i]);
 	 LogNote(9,"got file handle %s (%d)",handle_x.get(),handle_len);
 	 request_pos=real_pos=pos;
 	 if(mode==RETRIEVE)
 	    SendRequest(new Request_FSTAT(handle,
 	       SSH_FILEXFER_ATTR_SIZE|SSH_FILEXFER_ATTR_MODIFYTIME|SSH_FILEXFER_ATTR_PERMISSIONS,
 	       protocol_version),Expect::INFO);
-	 else if(mode==STORE)
+	 else if(mode==STORE && pos>0)
 	 {
 	    // truncate the file at write position.
 	    Request_FSETSTAT *req=new Request_FSETSTAT(handle,protocol_version);
@@ -1373,11 +1382,12 @@ void SFtp::Reconfig(const char *name)
       size_read=16;
    if(size_write<16)
       size_write=16;
+   use_full_path=QueryBool("use-full-path",c);
    if(!xstrcmp(name,"sftp:charset") && protocol_version && protocol_version<4)
    {
       if(!IsSuspended())
 	 cache->TreeChanged(this,"/");
-      const char *charset=ResMgr::Query("fish:charset",hostname);
+      const char *charset=ResMgr::Query("sftp:charset",hostname);
       if(charset && *charset)
       {
 	 if(!send_translate)
@@ -1387,6 +1397,11 @@ void SFtp::Reconfig(const char *name)
 	 send_translate->SetTranslation(charset,false);
 	 recv_translate->SetTranslation(charset,true);
       }
+      else
+      {
+	 send_translate=0;
+	 recv_translate=0;
+      }
    }
 }
 
