@@ -1,7 +1,7 @@
 /*
  * lftp - file transfer program
  *
- * Copyright (c) 1996-1999 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2007 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -50,7 +50,7 @@ void TreatFileJob::Begin(const char *d)
 void TreatFileJob::Finish()
 {
    /* next? */
-   char *d=args->getnext();
+   const char *d=args->getnext();
    if(d) {
       /* we have another argument */
       Begin(d);
@@ -73,7 +73,6 @@ TreatFileJob::prf_res TreatFileJob::ProcessFile(const char *d,const FileInfo *fi
 	 first=new FileInfo(*fi);
 
       TreatCurrent(d,fi);
-      return PRF_LATER;
    }
    int res=session->Done();
    if(res==FA::IN_PROGRESS)
@@ -86,7 +85,7 @@ TreatFileJob::prf_res TreatFileJob::ProcessFile(const char *d,const FileInfo *fi
    {
       failed++;
       if(!quiet)
-         fprintf(stderr,"%s: %s\n",op,session->StrError(res));
+         eprintf("%s: %s\n",op,session->StrError(res));
    }
    CurrentFinished(d,fi);
 
@@ -94,17 +93,16 @@ TreatFileJob::prf_res TreatFileJob::ProcessFile(const char *d,const FileInfo *fi
    return res<0? PRF_ERR:PRF_OK;
 }
 
-void  TreatFileJob::PrintStatus(int v)
+void  TreatFileJob::PrintStatus(int v,const char *prefix)
 {
-   SessionJob::PrintStatus(v);
+   SessionJob::PrintStatus(v,prefix);
    if(Done() || !curr)
       return;
-   printf("\t`%s' [%s]\n",curr->name,session->CurrentStatus());
+   printf("\t`%s' [%s]\n",curr->name.get(),session->CurrentStatus());
 }
 
-void  TreatFileJob::ShowRunStatus(StatusLine *s)
+void  TreatFileJob::ShowRunStatus(const SMTaskRef<StatusLine>& s)
 {
    if(curr && !Done())
-      s->Show("%s `%s' [%s]",op,curr->name,session->CurrentStatus());
+      s->Show("%s `%s' [%s]",op,curr->name.get(),session->CurrentStatus());
 }
-
