@@ -1,7 +1,7 @@
 /*
  * lftp and utils
  *
- * Copyright (c) 1996-2005 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2008 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -417,8 +417,7 @@ const char *url::encode(const char *s,const char *unsafe)
 {
    if(!s || !*s)
       return s;
-   static xstring u("");
-   u.truncate(0);
+   xstring& u=xstring::get_tmp("");
    char c;
    while((c=*s++))
    {
